@@ -65,18 +65,6 @@ pub fn html(conn: Conn, content: &str) -> Conn {
         resp_body: content.to_string(),
         status: 200,
         ..conn
-        //
-        // host: conn.host.clone(),
-        // method: conn.method.clone(),
-        // port: conn.port,
-        // scheme: conn.scheme.clone(),
-        // path: conn.path.clone(),
-        // query_string: conn.query_string.clone(),
-        // req_body: conn.req_body.clone(),
-        // req_headers: conn.req_headers.clone(),
-        // cf: conn.cf.clone(),
-        // assigns: conn.assigns.clone(),
-        // halted: conn.halted,
     };
 }
 
@@ -91,18 +79,6 @@ pub fn json(conn: Conn, content: &str) -> Conn {
         resp_body: content.to_string(),
         status: 200,
         ..conn
-        // //
-        // host: conn.host.clone(),
-        // method: conn.method.clone(),
-        // port: conn.port,
-        // scheme: conn.scheme.clone(),
-        // path: conn.path.clone(),
-        // query_string: conn.query_string.clone(),
-        // req_body: conn.req_body.clone(),
-        // req_headers: conn.req_headers.clone(),
-        // cf: conn.cf.clone(),
-        // assigns: conn.assigns.clone(),
-        // halted: conn.halted,
     };
 }
 
@@ -117,18 +93,56 @@ pub fn xml(conn: Conn, content: &str) -> Conn {
         resp_body: content.to_string(),
         status: 200,
         ..conn
-        //
-        // host: conn.host.clone(),
-        // method: conn.method.clone(),
-        // port: conn.port,
-        // scheme: conn.scheme.clone(),
-        // path: conn.path.clone(),
-        // query_string: conn.query_string.clone(),
-        // req_body: conn.req_body.clone(),
-        // req_headers: conn.req_headers.clone(),
-        // cf: conn.cf.clone(),
-        // assigns: conn.assigns.clone(),
-        // halted: conn.halted,
+    };
+}
+
+pub fn js(conn: Conn, content: &str) -> Conn {
+    let mut headers = conn.resp_headers;
+    headers.insert(
+        "Content-Type".to_string(),
+        "text/javascript; charset=utf-8".to_string(),
+    );
+    return Conn {
+        resp_headers: headers,
+        resp_body: content.to_string(),
+        status: 200,
+        ..conn
+    };
+}
+
+pub fn css(conn: Conn, content: &str) -> Conn {
+    let mut headers = conn.resp_headers;
+    headers.insert(
+        "Content-Type".to_string(),
+        "text/css; charset=utf-8".to_string(),
+    );
+    return Conn {
+        resp_headers: headers,
+        resp_body: content.to_string(),
+        status: 200,
+        ..conn
+    };
+}
+
+pub fn custom(conn: Conn, content: &str, content_type: &str) -> Conn {
+    let mut headers = conn.resp_headers;
+    headers.insert("Content-Type".to_string(), content_type.to_string());
+    return Conn {
+        resp_headers: headers,
+        resp_body: content.to_string(),
+        status: 200,
+        ..conn
+    };
+}
+
+pub fn redirect_to(conn: Conn, to: &str) -> Conn {
+    let mut headers = conn.resp_headers;
+    headers.insert("Location".to_string(), to.to_string());
+    return Conn {
+        resp_headers: headers,
+        resp_body: "".to_string(),
+        status: 200,
+        ..conn
     };
 }
 
