@@ -10,7 +10,7 @@ extern crate serde_derive;
 extern crate uuid;
 
 use conn::{conn_to_response, create_conn};
-pub use conn::{html, json, xml, Conn};
+pub use conn::{css, custom, html, js, json, redirect_to, xml, Conn};
 use routes::match_route;
 pub use routes::{Pattern, Route};
 use std::collections::HashMap;
